==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/StepFunctions/DeleteStateMachine.pm <==

package Paws::StepFunctions::DeleteStateMachine;
  use Moose;
  has StateMachineArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'stateMachineArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteStateMachine');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StepFunctions::DeleteStateMachineOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::DeleteStateMachine - Arguments for method DeleteStateMachine on Paws::StepFunctions

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteStateMachine on the 
AWS Step Functions service. Use the attributes of this class
as arguments to method DeleteStateMachine.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteStateMachine.

As an example:

  $service_obj->DeleteStateMachine(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> StateMachineArn => Str

The Amazon Resource Name (ARN) of the state machine to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteStateMachine in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/StepFunctions/DeleteStateMachine.pm <==

package Paws::StepFunctions::DeleteStateMachine;
  use Moose;
  has StateMachineArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'stateMachineArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteStateMachine');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StepFunctions::DeleteStateMachineOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::DeleteStateMachine - Arguments for method DeleteStateMachine on L<Paws::StepFunctions>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteStateMachine on the
L<AWS Step Functions|Paws::StepFunctions> service. Use the attributes of this class
as arguments to method DeleteStateMachine.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteStateMachine.

=head1 SYNOPSIS

    my $states = Paws->service('StepFunctions');
    my $DeleteStateMachineOutput = $states->DeleteStateMachine(
      StateMachineArn => 'MyArn',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/states/DeleteStateMachine>

=head1 ATTRIBUTES


=head2 B<REQUIRED> StateMachineArn => Str

The Amazon Resource Name (ARN) of the state machine to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteStateMachine in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
